@@ -1,5 +1,5 @@
 import logging
-from typing import AnyStr
+from typing import AnyStr, cast
 
 from dotify._model import Model, logger
 
@@ -9,9 +9,6 @@ logger = logging.getLogger("{0}.{1}".format(logger.name, __name__))
 class Artist(Model):
     """A class representing a Spotify `Artist`."""
 
-    class Json(object):
-        """ """
-
     @property
     def url(self) -> AnyStr:
         """Return the artist's Spotify URL.
@@ -19,7 +16,7 @@ class Artist(Model):
         Returns:
             AnyStr: the URL in string format
         """
-        return self.external_urls.spotify
+        return cast(AnyStr, self.external_urls.spotify)
 
     def __str__(self) -> AnyStr:
-        return self.name
+        return cast(AnyStr, self.name)
