@@ -8,8 +8,5 @@ logger = logging.getLogger("{0}.{1}".format(logger.name, __name__))
 class User(Model):
     """A model representing a Spotify `User`."""
 
-    class Json(object):
-        """ """
-
     def __str__(self):
         return self.display_name
